summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TFileUpload.php
diff options
context:
space:
mode:
authorxue <>2006-01-21 17:29:40 +0000
committerxue <>2006-01-21 17:29:40 +0000
commit3fcf847e0cadfb9ede930f538c2f277483442175 (patch)
tree12534cf4b29c1d4676fd59ab47adb60e292bcb6c /framework/Web/UI/WebControls/TFileUpload.php
parent99b56c855a597c606d349c7063d843539e65a6ed (diff)
BE AWARE: Significant change!
Changed event definition from XXX to OnXXX.
Diffstat (limited to 'framework/Web/UI/WebControls/TFileUpload.php')
-rw-r--r--framework/Web/UI/WebControls/TFileUpload.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/TFileUpload.php b/framework/Web/UI/WebControls/TFileUpload.php
index ba47f4d9..4a3d3a08 100644
--- a/framework/Web/UI/WebControls/TFileUpload.php
+++ b/framework/Web/UI/WebControls/TFileUpload.php
@@ -23,7 +23,7 @@
* file size information. If the upload is not successful, {@link getErrorCode ErrorCode}
* contains the error code describing the cause of failure.
*
- * TFileUpload raises {@link onFileUpload FileUpload} event if a file is uploaded
+ * TFileUpload raises {@link onFileUpload OnFileUpload} event if a file is uploaded
* (whether it succeeds or not).
*
* @author Marcus Nyeholt <tanus@users.sourceforge.net>, Qiang Xue <qiang.xue@gmail.com>
@@ -224,14 +224,14 @@ class TFileUpload extends TWebControl implements IPostBackDataHandler, IValidata
/**
* This method is invoked when a file is uploaded during a postback.
* The method raises <b>FileUpload</b> event to fire up the event handler.
* If you override this method, be sure to call the parent implementation
* so that the event delegates can be invoked.
* @param TEventParameter event parameter to be passed to the event handlers
*/
protected function onFileUpload($param)
{
- $this->raiseEvent('FileUpload',$this,$param);
+ $this->raiseEvent('OnFileUpload',$this,$param);
}
/**
@@ -224,14 +224,14 @@ class TFileUpload extends TWebControl implements IPostBackDataHandler, IValidata
/**
* This method is invoked when a file is uploaded during a postback.
- * The method raises <b>FileUpload</b> event to fire up the event handler.
+ * The method raises <b>OnFileUpload</b> event to fire up the event handler.
* If you override this method, be sure to call the parent implementation
* so that the event delegates can be invoked.